``` bash
aea create my_aea --author "fetchai"
cd my_aea
```
``` bash
aea scaffold skill my_skill
```
``` bash
aea scaffold protocol my_protocol
```
``` bash
aea scaffold contract my_contract
```
``` bash
aea scaffold connection my_connection
```
``` bash
aea fingerprint [package_name] [public_id]
```
